from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ArtdPartnerConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    verbose_name = _("ArtD Partner")
    name = "artd_partner"

    def ready(self):
        from artd_partner import signals  # noqa: F401


# Generated by Django 5.0.1 on 2024-03-04 05:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0001_initial"),
        ("artd_partner", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coworker",
            name="dni",
            field=models.CharField(
                help_text="DNI of coworker", max_length=20, verbose_name="Dni"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="first_name",
            field=models.CharField(
                help_text="First name of coworker",
                max_length=150,
                verbose_name="First name",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="headquarter",
            field=models.ForeignKey(
                help_text="Headquarter of coworker",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_partner.headquarter",
                verbose_name="Headquarter",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="last_name",
            field=models.CharField(
                help_text="Last name of coworker",
                max_length=150,
                verbose_name="Last name",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="phone",
            field=models.CharField(
                help_text="Phone of coworker", max_length=20, verbose_name="Phone"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="position",
            field=models.ForeignKey(
                help_text="Position of coworker",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_partner.position",
                verbose_name="Position",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="address",
            field=models.CharField(
                help_text="Address of headquarter",
                max_length=250,
                verbose_name="Address",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="city",
            field=models.ForeignKey(
                help_text="City of headquarter",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="name",
            field=models.CharField(
                help_text="Name of headquarter", max_length=150, verbose_name="Name"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="address",
            field=models.CharField(
                help_text="Address of partner", max_length=250, verbose_name="Address"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="city",
            field=models.ForeignKey(
                help_text="City of partner",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="dni",
            field=models.CharField(
                help_text="DNI of partner", max_length=20, verbose_name="Dni"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="email",
            field=models.EmailField(
                help_text="Email of partner", max_length=254, verbose_name="Email"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="name",
            field=models.CharField(
                help_text="Name of partner", max_length=150, verbose_name="Name"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="partner_slug",
            field=models.SlugField(
                help_text="Slug of headquarter", max_length=150, verbose_name="Slug"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="name",
            field=models.CharField(
                help_text="Name of position", max_length=150, verbose_name="Name"
            ),
        ),
    ]



# Generated by Django 5.0.6 on 2024-07-27 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
        ('artd_service', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='partner',
            name='services',
            field=models.ManyToManyField(help_text='Services of partner', to='artd_service.service', verbose_name='Services'),
        ),
    ]



from django.contrib import admin

# Register your models here.
from django.contrib import admin
from artd_partner.models import Partner, Headquarter, Position, Coworker
from django.utils.translation import gettext_lazy as _


@admin.register(Partner)
class PartnerAdmin(admin.ModelAdmin):
    """Admin view for Partner."""

    list_display = (
        "name",
        "id",
        "partner_slug",
        "dni",
        "address",
        "city",
    )
    list_filter = (
        "city",
        "partner_slug",
    )
    search_fields = (
        "name",
        "partner_slug",
        "dni",
        "address",
        "city__name",
    )
    readonly_fields = (
        "updated_at",
        "created_at",
    )
    fieldsets = (
        (
            _("Partner"),
            {
                "fields": (
                    "name",
                    "partner_slug",
                    "dni",
                    "address",
                    "city",
                )
            },
        ),
        (
            _("Services"),
            {"fields": ("services",)},
        ),
        (
            _("Status"),
            {"fields": ("status",)},
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )


@admin.register(Headquarter)
class HeadquarterAdmin(admin.ModelAdmin):
    """Admin view for Headquarter."""

    list_display = (
        "name",
        "id",
        "partner",
        "address",
        "city",
        "phone",
        "status",
    )
    list_filter = (
        "city",
        "partner",
    )
    readonly_fields = (
        "updated_at",
        "created_at",
    )
    search_fields = (
        "name",
        "address",
        "city__name",
        "phone",
        "partner__name",
    )
    fieldsets = (
        (
            _("Headquarter"),
            {
                "fields": (
                    "name",
                    "partner",
                    "address",
                    "city",
                    "phone",
                )
            },
        ),
        (
            _("Status"),
            {"fields": ("status",)},
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )


@admin.register(Position)
class PositionAdmin(admin.ModelAdmin):
    """Admin view for Position."""

    list_display = (
        "name",
        "status",
    )
    search_fields = ("name",)
    readonly_fields = (
        "updated_at",
        "created_at",
    )
    fieldsets = (
        (
            _("Position"),
            {"fields": ("name",)},
        ),
        (
            _("Status"),
            {"fields": ("status",)},
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )


@admin.register(Coworker)
class CoworkerAdmin(admin.ModelAdmin):
    """Admin view for Coworker."""

    list_display = (
        "first_name",
        "last_name",
        "id",
        "dni",
        "phone",
        "position",
        "headquarter",
        "status",
    )
    readonly_fields = (
        "updated_at",
        "created_at",
    )
    search_fields = (
        "first_name",
        "last_name",
        "dni",
        "phone",
        "position__name",
        "headquarter__name",
    )
    fieldsets = (
        (
            _("Coworker"),
            {
                "fields": (
                    "first_name",
                    "last_name",
                    "email",
                    "dni",
                    "phone",
                    "position",
                    "headquarter",
                )
            },
        ),
        (
            _("Status"),
            {"fields": ("status",)},
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    list_filter = (
        "position",
        "headquarter",
    )



# Generated by Django 5.0.1 on 2024-03-09 14:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "artd_partner",
            "0004_alter_coworker_created_at_alter_coworker_updated_at_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="coworker",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
    ]
